// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// 
// http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

var DateRangeFilter = function (container_id, value_container_id, min, max, default_min, default_max) {
    this.init(container_id, value_container_id, min, max, default_min, default_max);
};


//Inheritance
DateRangeFilter.prototype = new Filter();
DateRangeFilter.prototype.constructor = DateRangeFilter;
DateRangeFilter.superclass = Filter.prototype;

DateRangeFilter.prototype.init = function (container_id, value_container_id, min, max, default_min, default_max) {
	
	DateRangeFilter.superclass.init.call(this)
	
	this.container = $(container_id)
	
	$(value_container_id).html('From: <span class="min"></span> to: <span class="max"></span>')
	this.value_min_container = $(value_container_id + ' .min')
	this.value_max_container = $(value_container_id + ' .max')
	
	this.min = min;
	this.max = max;
	this.default_min = default_min;
	this.default_max = default_max;
	this.value_min = default_min * 86400000;
	this.value_max = default_max * 86400000;
	
};

DateRangeFilter.prototype.render = function() {
	
	this.container.slider({
				range: true,
				min: this.min,
				max: this.max,
				values: [ this.default_min, this.default_max ],
				slide: bind(this, this.callback),
				stop: function() {Filters.applyFilters();}
			});
	
	this.updateValueContainer((new Date(this.value_min)), (new Date(this.value_max)))
}

DateRangeFilter.prototype.callback = function(event, ui) {
	
	this.value_min = ui.values[ 0 ] * 86400000
	this.value_max = ui.values[ 1 ] * 86400000
	
	this.updateValueContainer((new Date(this.value_min)), (new Date(this.value_max)))
	
}

DateRangeFilter.prototype.updateValueContainer = function(date_min, date_max) {

	this.value_min_container.html( pad2(date_min.getDate()) + '/' + pad2(date_min.getMonth()+1) + '/' + date_min.getFullYear() )
	this.value_max_container.html( pad2(date_max.getDate()) + '/' + pad2(date_max.getMonth()+1) + '/' + date_max.getFullYear() )
}

DateRangeFilter.prototype.testImage = function(image) {
	
	if ( (image.datetaken >= this.value_min)
	  && (image.datetaken <= this.value_max) ) {
		
		return true
	} else {
		
		return false
	}

}